@@ -4,11 +4,11 @@
 #' association corrected for unknown or unmeasured confounding without effect
 #' modification.
 #'
-#' `confounders.emm()` allows to provide for adjusted measures of association
+#' `confounders_emm()` allows to provide for adjusted measures of association
 #' corrected for unknown or unmeasured confounding in the presence of effect
 #' modification.
 #'
-#' `confounders.poly()` allows to provide for adjusted measures of association
+#' `confounders_poly()` allows to provide for adjusted measures of association
 #' corrected for unknown or unmeasured polychotomous (3-level) confounding without
 #' effect modification.
 #'
@@ -35,14 +35,14 @@
 #' controls can be specified and use the NORmal To Anything (NORTA)
 #' transformation (Li & Hammond, 1975).
 #'
-#' @section Simple bias analysis with `confounders.emm()`:
-#' `confounders.emm()` allows you to run a simple sensitivity analysis to correct
+#' @section Simple bias analysis with `confounders_emm()`:
+#' `confounders_emm()` allows you to run a simple sensitivity analysis to correct
 #' for unknown or unmeasured confounding in the presence of effect modification.
 #' Implementation for ratio measures (relative risk -- RR, or odds ratio -- OR)
 #' and difference measures (risk difference -- RD).
 #'
-#' @section Simple bias analysis with `confounders.poly()`:
-#' `confounders.poly()` allows you to run a simple sensitivity analysis to correct
+#' @section Simple bias analysis with `confounders_poly()`:
+#' `confounders_poly()` allows you to run a simple sensitivity analysis to correct
 #' for unknown or unmeasured polychotomous (3-level) confounding without effect
 #' modification. Implementation for ratio measures (relative risk -- RR, or odds
 #' ratio -- OR) and difference measures (risk difference -- RD).
@@ -58,7 +58,7 @@
 #'
 #' ```
 #' library(episensr)
-#' probsens.conf <- probsens.conf_legacy
+#' probsens_conf <- probsens.conf_legacy
 #' ```
 #'
 #' @param case Outcome variable. If a variable, this variable is tabulated against.
@@ -76,7 +76,7 @@
 #'          \item the prevalence of the confounder among the exposed (between 0 and 1), and
 #'          \item the prevalence of the confounder among the unexposed (between 0 and 1).
 #'        }
-#'     \item This vector has 4 elements for the `confounders.emm()` function, in the
+#'     \item This vector has 4 elements for the `confounders_emm()` function, in the
 #'     following order:
 #'       \enumerate{
 #'          \item the association between the confounder and the outcome among those who
@@ -86,7 +86,7 @@
 #'          \item the prevalence of the confounder among the exposed (between 0 and 1), and
 #'          \item the prevalence of the confounder among the unexposed (between 0 and 1).
 #'       }
-#'     \item This vector has 6 elements for the `confounders.poly()` function, in the
+#'     \item This vector has 6 elements for the `confounders_poly()` function, in the
 #'     following order:
 #'       \enumerate{
 #'         \item the association between the highest level confounder and the outcome,
@@ -102,8 +102,8 @@
 #' @return A list with elements:
 #' \item{obs_data}{The analyzed 2 x 2 table from the observed data.}
 #' \item{cfder_data}{The same table for Confounder +.}
-#' \item{cfder1.data}{The same table for Mid-level Confounder + (for `confounders.poly()`).}
-#' \item{cfder2.data}{The same table for Highest-level Confounder + (for `confounders.poly()`).}
+#' \item{cfder1.data}{The same table for Mid-level Confounder + (for `confounders_poly()`).}
+#' \item{cfder2.data}{The same table for Highest-level Confounder + (for `confounders_poly()`).}
 #' \item{nocfder_data}{The same table for Confounder -.}
 #' \item{obs_measures}{A table of relative risk with confidence intervals; for
 #'   Total, Confounder +, and Confounder -.}
@@ -274,7 +274,7 @@ in adjusted 2x2 table(s).")))
         C0 <- c - C1
         D0 <- d - D1
         M0 <- A0 + C0
-        N0 <- B0 + C0
+        N0 <- B0 + D0
 
         if (A1 < 0 | B1 < 0 | C1 < 0 | D1 < 0 | A0 < 0 | B0 < 0 | C0 < 0 | D0 < 0)
             stop(cli::format_error(c("x" = "Parameters chosen lead to negative cell(s)
@@ -410,26 +410,26 @@ cell(s) in adjusted 2x2 table(s).")))
 #' @rdname confounders
 #' @examples
 #' #
-#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' confounders_emm(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "RR",
 #' bias_parms = c(.4, .7, .8, .05))
 #'
-#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' confounders_emm(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "OR",
 #' bias_parms = c(.4, .7, .8, .05))
 #'
-#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' confounders_emm(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "RD",
 #' bias_parms = c(-.6, -.3, .8, .05))
 #' @export
 #' @importFrom stats qnorm
-confounders.emm <- function(case,
+confounders_emm <- function(case,
                             exposed,
                             type = c("RR", "OR", "RD"),
                             bias_parms = NULL,
@@ -691,26 +691,26 @@ cell(s) in adjusted 2x2 table(s).")))
 #' # Increased risk of infection with human immunodeficiency virus type 1 among
 #' # uncircumcised men presenting with genital ulcer disease in Kenya.
 #' # Clin Infect Dis 1996;23:449-53.
-#' confounders.poly(matrix(c(105, 85, 527, 93),
+#' confounders_poly(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "RR",
 #' bias_parms = c(.4, .8, .6, .05, .2, .2))
 #'
-#' confounders.poly(matrix(c(105, 85, 527, 93),
+#' confounders_poly(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "OR",
 #' bias_parms = c(.4, .8, .6, .05, .2, .2))
 #'
-#' confounders.poly(matrix(c(105, 85, 527, 93),
+#' confounders_poly(matrix(c(105, 85, 527, 93),
 #' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
 #' nrow = 2, byrow = TRUE),
 #' type = "RD",
 #' bias_parms = c(-.4, -.2, .6, .05, .2, .2))
 #' @export
 #' @importFrom stats qnorm
-confounders.poly <- function(case,
+confounders_poly <- function(case,
                              exposed,
                              type = c("RR", "OR", "RD"),
                              bias_parms = NULL,
@@ -1277,7 +1277,7 @@ meanlog and sdlog.")))
     if (!is.null(corr_p) && (corr_p == 0 | corr_p == 1))
         stop(cli::format_error(c("x" = "Correlations should be > 0 and < 1.")))
 
-    if (!inherits(case, "episensr.probsens")) {
+    if (!inherits(case, "episensr_probsens")) {
         if (inherits(case, c("table", "matrix")))
             tab <- case
         else {
@@ -1487,7 +1487,7 @@ sampled cell counts w{?as/ere} zero and discarded.")
                 quantile(draws[, 21], probs = .025, na.rm = TRUE),
                 quantile(draws[, 21], probs = .975, na.rm = TRUE))
 
-    if (!inherits(case, "episensr.probsens")) {
+    if (!inherits(case, "episensr_probsens")) {
         tab <- tab
         rmat <- rbind(c(obs_rr, lci_obs_rr, uci_obs_rr),
                       c(obs_or, lci_obs_or, uci_obs_or))
@@ -1517,6 +1517,6 @@ sampled cell counts w{?as/ere} zero and discarded.")
                 reps = reps,
                 fun = "probsens_conf",
                 warnings = neg_warn)
-    class(res) <- c("episensr", "episensr.probsens", "list")
+    class(res) <- c("episensr", "episensr_probsens", "list")
     res
 }
