@@ -357,7 +357,7 @@ in adjusted 2x2 table.")))
                 obs_measures = rmat,
                 adj_measures = rmatc,
                 bias_parms = bias_parms)
-    class(res) <- c("episensr", "episensr.boot", "list")
+    class(res) <- c("episensr", "episensr_boot", "list")
     res
 }
 
@@ -392,6 +392,7 @@ in adjusted 2x2 table.")))
 #'   \item Negative predictive value among those with the outcome,
 #'   \item Negative predictive value among those without the outcome.
 #'   }
+#' @param seca.parms Deprecated. Please use `seca`.
 #' @param seexp List defining sensitivity among controls:
 #'   \enumerate{
 #'   \item The sensitivity of exposure classification among those without the
@@ -399,11 +400,16 @@ in adjusted 2x2 table.")))
 #'   \item The sensitivity of outcome classification among those without the
 #'   exposure (when \code{type = "outcome"}).
 #'   }
+#' @param seexp.parms Deprecated. Please use `seexp`.
 #' @param spca List as above for \code{seca} but for specificity.
+#' @param spca.parms Deprecated. Please use `spca`.
 #' @param spexp List as above for \code{seexp} but for specificity.
+#' @param spexp.parms Deprecated. Please use `spexp`.
 #' @param corr_se Correlation between case and non-case sensitivities. If PPV/NPV is
 #' chosen in case of exposure misclassification, correlations are set to NULL.
+#' @param corr.se Deprecated. Please use `corr_se`.
 #' @param corr_sp Correlation between case and non-case specificities.
+#' @param corr.sp Deprecated. Please use `corr_sp`.
 #'
 #' @return A list with elements (for `probsens()`):
 #'   \item{obs_data}{The analyzed 2 x 2 table from the observed data.}
@@ -526,9 +532,40 @@ probsens <- function(case,
                                           "normal", "beta"),
                                  parms = NULL),
                      spexp = NULL,
+                     seca.parms = deprecated(),
+                     seexp.parms = deprecated(),
+                     spca.parms = deprecated(),
+                     spexp.parms = deprecated(),
                      corr_se = NULL,
+                     corr.se = deprecated(),
                      corr_sp = NULL,
+                     corr.sp = deprecated(),
                      alpha = 0.05) {
+    if (lifecycle::is_present(seca.parms)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(seca.parms)", "probsens(seca)")
+        seca <- seca.parms
+    }
+    if (lifecycle::is_present(seexp.parms)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(seexp.parms)", "probsens(seexp)")
+        seexp <- seexp.parms
+    }
+    if (lifecycle::is_present(spca.parms)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(spca.parms)", "probsens(spca)")
+        spca <- spca.parms
+    }
+    if (lifecycle::is_present(spexp.parms)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(spexp.parms)", "probsens(spexp)")
+        spexp <- spexp.parms
+    }
+    if (lifecycle::is_present(corr.se)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(corr.se)", "probsens(corr_se)")
+        corr_se <- corr.se
+    }
+    if (lifecycle::is_present(corr.sp)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens(corr.sp)", "probsens(corr_sp)")
+        corr_sp <- corr.sp
+    }
+
     if (reps < 1)
         stop(cli::format_error(c("x" = "Wrong number of replications: reps = {reps}",
                                  "i" = "reps must be >= 1")))
@@ -755,7 +792,7 @@ Se and Sp correlations.")))
     if (!is.null(corr_sp) && (corr_sp == 0 | corr_sp == 1))
         stop(cli::format_error(c("x" = "Correlations should be > 0 and < 1.")))
 
-    if (!inherits(case, "episensr.probsens")) {
+    if (!inherits(case, "episensr_probsens")) {
         if (inherits(case, c("table", "matrix")))
             tab <- case
         else {
@@ -1017,7 +1054,7 @@ Se and Sp correlations.")))
                     quantile(draws[, 26], probs = .025, na.rm = TRUE),
                     quantile(draws[, 26], probs = .975, na.rm = TRUE))
 
-        if (!inherits(case, "episensr.probsens")) {
+        if (!inherits(case, "episensr_probsens")) {
             tab <- tab
             rmat <- rbind(c(obs_rr, lci_obs_rr, uci_obs_rr),
                           c(obs_or, lci_obs_or, uci_obs_or))
@@ -1064,7 +1101,7 @@ Se and Sp correlations.")))
                      quantile(draws[, 12], probs = .025, na.rm = TRUE),
                      quantile(draws[, 12], probs = .975, na.rm = TRUE))
 
-        if (!inherits(case, "episensr.probsens")) {
+        if (!inherits(case, "episensr_probsens")) {
             tab <- tab
             rmat <- rbind(c(obs_rr, lci_obs_rr, uci_obs_rr),
                           c(obs_or, lci_obs_or, uci_obs_or))
@@ -1167,7 +1204,7 @@ Se and Sp correlations.")))
                     quantile(draws[, 26], probs = .025, na.rm = TRUE),
                     quantile(draws[, 26], probs = .975, na.rm = TRUE))
 
-        if (!inherits(case, "episensr.probsens")) {
+        if (!inherits(case, "episensr_probsens")) {
             tab <- tab
             rmat <- rbind(c(obs_rr, lci_obs_rr, uci_obs_rr),
                           c(obs_or, lci_obs_or, uci_obs_or))
@@ -1214,6 +1251,6 @@ Se and Sp correlations.")))
                     )
     }
 
-    class(res) <- c("episensr", "episensr.probsens", "list")
+    class(res) <- c("episensr", "episensr_probsens", "list")
     res
 }
