@@ -1,14 +1,14 @@
 #' Selection bias.
 #'
-#' `selection()` and `probsens.sel()` allow to provide adjusted measures of
+#' `selection()` and `probsens_sel()` allow to provide adjusted measures of
 #' association corrected for selection bias.
 #'
 #' @section Simple bias analysis with `selection()`:
 #' `selection()` allows you to run a simple sensitivity analysis to correct for
 #' selection bias using estimates of the selection proportions.
 #'
-#' @section Probabilistic sensitivity analysis with `probsens.sel()`:
-#' `probsens.sel()` performs a summary-level probabilistic sensitivity analysis to
+#' @section Probabilistic sensitivity analysis with `probsens_sel()`:
+#' `probsens_sel()` performs a summary-level probabilistic sensitivity analysis to
 #' correct for selection bias.
 #'
 #' @param case Outcome variable. If a variable, this variable is tabulated
@@ -152,7 +152,7 @@ selection <- function(case,
                 adj_measures = rmatc,
                 bias_parms = bias_parms,
                 selbias_or = selbias)
-    class(res) <- c("episensr", "episensr.boot", "list")
+    class(res) <- c("episensr", "episensr_boot", "list")
     res
 }
 
@@ -170,12 +170,16 @@ selection <- function(case,
 #'   \item normal: truncated normal with lower bound, upper bound, mean, sd,
 #'   \item beta: alpha, beta.
 #'   }
+#' @param case.exp Deprecated. Please use `case_exp`.
 #' @param case_nexp Same among cases non-exposed.
+#' @param case.nexp Deprecated. Please use `case_nexp`.
 #' @param ncase_exp Same among non-cases exposed.
+#' @param ncase.exp Deprecated. Please use `ncase_exp`.
 #' @param ncase_nexp Same among non-cases non-exposed.
+#' @param ncase.nexp Deprecated. Please use `ncase_nexp`.
 #' @param alpha Significance level.
 #'
-#' @return A list with elements (for `probsens.sel()`):
+#' @return A list with elements (for `probsens_sel()`):
 #' \item{obs_data}{The analyzed 2 x 2 table from the observed data.}
 #' \item{obs_measures}{A table of observed odds ratio with confidence intervals.}
 #' \item{adj_measures}{A table of corrected odds ratios.}
@@ -190,7 +194,7 @@ selection <- function(case,
 #' # Supplementing cancer registry data by case-control data.
 #' # Eur J Cancer Prev 2006;15:165-70.
 #' set.seed(1234)
-#' probsens.sel(matrix(c(139, 114, 369, 377),
+#' probsens_sel(matrix(c(139, 114, 369, 377),
 #' dimnames = list(c("Melanoma+", "Melanoma-"), c("Mobile+", "Mobile-")), nrow = 2, byrow = TRUE),
 #' reps = 5000,
 #' case_exp = list("beta", c(139, 5.1)),
@@ -199,26 +203,51 @@ selection <- function(case,
 #' ncase_nexp = list("beta", c(377, 282.9)))
 #' @export
 #' @importFrom stats median qnorm quantile runif rlnorm rbeta
-probsens.sel <- function(case,
+probsens_sel <- function(case,
                          exposed,
                          reps = 1000,
                          case_exp = list(dist = c("constant", "uniform",
                                                   "triangular", "trapezoidal",
                                                   "normal", "beta"),
                                          parms = NULL),
+                         case.exp = deprecated(),
                          case_nexp = list(dist = c("constant", "uniform",
                                                    "triangular", "trapezoidal",
                                                    "normal", "beta"),
                                           parms = NULL),
+                         case.nexp = deprecated(),
                          ncase_exp = list(dist = c("constant", "uniform",
                                                    "triangular", "trapezoidal",
                                                    "normal", "beta"),
                                           parms = NULL),
+                         ncase.exp = deprecated(),
                          ncase_nexp = list(dist = c("constant", "uniform",
                                                     "triangular", "trapezoidal",
                                                     "normal", "beta"),
                                            parms = NULL),
+                         ncase.nexp = deprecated(),
                          alpha = 0.05) {
+    if (lifecycle::is_present(case.exp)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens.sel(case.exp)",
+                                  "probsens.sel(case_exp)")
+        case_exp <- case.exp
+    }
+    if (lifecycle::is_present(case.nexp)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens.sel(case.nexp)",
+                                  "probsens.sel(case_nexp)")
+        case_nexp <- case.nexp
+    }
+    if (lifecycle::is_present(ncase.exp)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens.sel(ncase.exp)",
+                                  "probsens.sel(ncase_exp)")
+        ncase_exp <- ncase.exp
+    }
+    if (lifecycle::is_present(ncase.nexp)) {
+        lifecycle::deprecate_warn("2.1.0", "probsens.sel(ncase.nexp)",
+                                  "probsens.sel(ncase_nexp)")
+        ncase_nexp <- ncase.nexp
+    }
+
     if (reps < 1)
         stop(cli::format_error(c("x" = "Wrong number of replications: reps = {reps}",
                                  "i" = "reps must be >= 1")))
@@ -361,7 +390,7 @@ vector of lower limit, lower mode, upper mode, and upper limit.")))
     }
 
 
-    if (!inherits(case, "episensr.probsens")) {
+    if (!inherits(case, "episensr_probsens")) {
         if (inherits(case, c("table", "matrix")))
             tab <- case
         else {
@@ -557,7 +586,7 @@ vector of lower limit, lower mode, upper mode, and upper limit.")))
                 adj_measures = rmatc,
                 sim_df = as.data.frame(draws[, -c(13, 18)]),
                 reps = reps,
-                fun = "probsens.sel")
-    class(res) <- c("episensr", "episensr.probsens", "list")
+                fun = "probsens_sel")
+    class(res) <- c("episensr", "episensr_probsens", "list")
     res
 }
