@@ -10,7 +10,7 @@ misclass_eval <- misclass(matrix(c(215, 1449, 668, 4296),
                           type = "exposure",
                           bias_parms = c(.78, .78, .99, .99))
 set.seed(123)
-mod <- boot.bias(misclass_eval)
+mod <- boot_bias(misclass_eval)
 
 
 test_that("RR and OR are correct, misclass + CI norm", {
@@ -22,7 +22,7 @@ test_that("RR and OR are correct, misclass + CI norm", {
 
 # Misclassification, ci == perc
 set.seed(123)
-mod <- boot.bias(misclass_eval, ci_type = "perc")
+mod <- boot_bias(misclass_eval, ci_type = "perc")
 
 
 test_that("RR and OR are correct, misclass + CI perc", {
@@ -38,7 +38,7 @@ sel <- selection(matrix(c(136, 107, 297, 165),
                         nrow = 2, byrow = TRUE),
                  bias_parms = c(.94, .85, .64, .25))
 set.seed(123)
-mod <- boot.bias(sel)
+mod <- boot_bias(sel)
 
 
 test_that("RR and OR are correct, selection + CI norm", {
@@ -51,7 +51,7 @@ test_that("RR and OR are correct, selection + CI norm", {
 
 # Selection, ci == perc
 set.seed(123)
-mod <- boot.bias(sel, ci_type = "perc")
+mod <- boot_bias(sel, ci_type = "perc")
 
 
 test_that("RR and OR are correct, selection + CI perc", {
