@@ -541,20 +541,20 @@ test_that("Selection bias: adjusted measures are correct (beta)", {
 test_that("correct arguments --- list", {
     expect_that(probsens_conf(matrix(c(105, 85, 527, 93), nrow = 2, byrow = TRUE),
                              reps = 1000,
-                             prev.exp = c("uniform", 1, 2),
-                             prev.nexp = list("beta", c(10, 16)),
+                             prev_exp = c("uniform", 1, 2),
+                             prev_nexp = list("beta", c(10, 16)),
                              risk = list("triangular", c(.6, .7, .63)),
-                             corr.p = .8),
+                             corr_p = .8),
                 throws_error())
 })
 
 test_that("correct arguments --- distribution", {
     expect_that(probsens_conf(matrix(c(105, 85, 527, 93), nrow = 2, byrow = TRUE),
                              reps = 1000,
-                             prev.exp = list(c("uniform", "beta"), c(10, 16)),
-                             prev.nexp = list("beta", c(10, 16)),
+                             prev_exp = list(c("uniform", "beta"), c(10, 16)),
+                             prev_nexp = list("beta", c(10, 16)),
                              risk = list("triangular", c(.6, .7, .63)),
-                             corr.p = .8),
+                             corr_p = .8),
                 throws_error())
 })
 
@@ -707,32 +707,32 @@ test_that("Confounding bias: book is correct", {
 })
 
 test_that("correct arguments --- list (IRR)", {
-    expect_that(probsens.irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
-                         reps = 1000,
-                         seca.parms = c("beta", c(900, 10)),
-                         spca.parms = list("constant", 1)),
+    expect_that(probsens_irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
+                             reps = 1000,
+                             seca = c("beta", c(900, 10)),
+                             spca = list("constant", 1)),
                 throws_error())
 })
 
 test_that("correct arguments --- list (IRR)", {
-    expect_that(probsens.irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
-                         reps = 1000,
-                         seca.parms = list("beta", c(-1, 10)),
-                         spca.parms = list("constant", 1)),
+    expect_that(probsens_irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
+                             reps = 1000,
+                             seca = list("beta", c(-1, 10)),
+                             spca = list("constant", 1)),
                 throws_error())
 })
 
 test_that("correct arguments --- list (IRR)", {
-    expect_that(probsens.irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
-                         reps = 1000,
-                         seca.parms = list("beta", "uniform", c(900, 10)),
-                         spca.parms = list("constant", 1)),
+    expect_that(probsens_irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
+                             reps = 1000,
+                             seca = list("beta", "uniform", c(900, 10)),
+                             spca = list("constant", 1)),
                 throws_error())
     })
 
 test_that("IRR exposure misclassification: observed measures are correct", {
     set.seed(123)
-    model <- probsens.irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
+    model <- probsens_irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
                           reps = 10000,
                           seca = list("trapezoidal", c(.4, .45, .55, .6)),
                           spca = list("constant", 1))
@@ -743,7 +743,7 @@ test_that("IRR exposure misclassification: observed measures are correct", {
 
 test_that("IRR exposure misclassification: adjusted measures are correct", {
     set.seed(123)
-    model <- probsens.irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
+    model <- probsens_irr(matrix(c(2, 67232, 58, 10539000), nrow = 2, byrow = TRUE),
                           reps = 10000,
                           seca = list("trapezoidal", c(.4, .45, .55, .6)),
                           spca = list("constant", 1))
@@ -756,23 +756,23 @@ test_that("IRR exposure misclassification: adjusted measures are correct", {
 })
 
 test_that("correct arguments --- list", {
-    expect_that(probsens.irr.conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
-                         reps = 1000,
-                         prev.exp = c("uniform", 1, 2),
-                         prev.nexp = list("beta", c(10, 16)),
-                         risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
-                         corr.p = .8),
+    expect_that(probsens_irr_conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
+                                  reps = 1000,
+                                  prev_exp = c("uniform", 1, 2),
+                                  prev_nexp = list("beta", c(10, 16)),
+                                  risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
+                                  corr_p = .8),
                 throws_error())
 })
 
 test_that("IRR confounding bias: observed measures are correct", {
     set.seed(123)
-    model <- probsens.irr.conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
-                      reps = 20000,
-                      prev_exp = list("trapezoidal", c(.01, .2, .3, .51)),
-                      prev_nexp = list("trapezoidal", c(.09, .27, .35, .59)),
-                      risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
-                      corr_p = .8)
+    model <- probsens_irr_conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
+                               reps = 20000,
+                               prev_exp = list("trapezoidal", c(.01, .2, .3, .51)),
+                               prev_nexp = list("trapezoidal", c(.09, .27, .35, .59)),
+                               risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
+                               corr_p = .8)
     expect_equal(model$obs_measures[1, 1], 0.8851, tolerance = 1e-4, scale = 1)
     expect_equal(model$obs_measures[1, 2], 0.6979, tolerance = 1e-4, scale = 1)
     expect_equal(model$obs_measures[1, 3], 1.1072, tolerance = 1e-4, scale = 1)
@@ -780,12 +780,12 @@ test_that("IRR confounding bias: observed measures are correct", {
 
 test_that("IRR Confounding bias: adjusted measures are correct", {
     set.seed(123)
-    model <- probsens.irr.conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
-                      reps = 20000,
-                      prev_exp = list("trapezoidal", c(.01, .2, .3, .51)),
-                      prev_nexp = list("trapezoidal", c(.09, .27, .35, .59)),
-                      risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
-                      corr_p = .8)
+    model <- probsens_irr_conf(matrix(c(77, 10000, 87, 10000), nrow = 2, byrow = TRUE),
+                               reps = 20000,
+                               prev_exp = list("trapezoidal", c(.01, .2, .3, .51)),
+                               prev_nexp = list("trapezoidal", c(.09, .27, .35, .59)),
+                               risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
+                               corr_p = .8)
     expect_equal(model$adj_measures[1, 1], 0.9701, tolerance = 1e-4, scale = 1)
     expect_equal(model$adj_measures[1, 2], 0.8199, tolerance = 1e-4, scale = 1)
     expect_equal(model$adj_measures[1, 3], 1.1804, tolerance = 1e-4, scale = 1)
